package org.artifactory.event.queue;

import org.artifactory.common.repo.PackageType;
import org.artifactory.common.repo.RepoType;

import java.util.List;
import java.util.Set;

/**
 * This is the main registration interface for the persistent queue framework.
 * Application code needs to implement this interface and return a list of QueueConfigurations
 * By implementing either getRepoType() and/or getRepoDetailsType(), code can filter out unwanted repoKeys
 *
 * @author Avishay Halpren
 */
public interface QueueConfigurationRegistrar {

    /**
     * implement this to get only repos of this type. e.g: Maven,Npm,Docker ...
     * if left empty no filter will be done on repos
     */
    default PackageType getPackageType() {
        return null;
    }

    /**
     * implement this to get only repos of this type. e.g: Local,Remote,Virtual ...
     * if left empty no filter will be done on repos.
     * For remote local cache return: remote,local
     */
    default Set<RepoType> getRepoTypes() {
        return Set.of();
    }

    List<QueueConfiguration> getConfigurations(String repoKey);

}
