package org.artifactory.storage.db;

import org.artifactory.storage.db.version.ArtifactoryDBVersion;
import org.artifactory.storage.db.version.converter.LockingDBSqlConverter;
import org.artifactory.util.CollectionUtils;
import org.jfrog.converter.DbConverter;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.invocation.InvocationOnMock;

import static org.mockito.Mockito.doAnswer;
import static org.mockito.Mockito.mock;

/**
 * Verify that DatabaseConverterAdapter and  LockingDBConverterAdapter process the
 * right DBConverters
 * <p>DatabaseConverterAdapter: all</p>
 * <p>LockingDBConverterAdapter: only converters that supports locking db</p>
 */

class DatabaseConverterAdapterTest {

    private DatabaseConverterAdapter databaseConverterAdapter = null;

    @BeforeEach
    public void setUp() {
        databaseConverterAdapter = mock(DatabaseConverterAdapter.class);
        doAnswer(InvocationOnMock::callRealMethod).when(databaseConverterAdapter).getDBConverters();

        LockingDBConverterAdapter lockingDBConverterAdapter = mock(LockingDBConverterAdapter.class);
        doAnswer(InvocationOnMock::callRealMethod).when(lockingDBConverterAdapter).getDBConverters();

    }

    /**
     * This test verify that DatabaseConverterAdapter.getDBConverters(...) returns all converters
     */
    @Test
    void testDatabaseConverterAdapterGetDBConvertersReturnsAllDBConverters() {
        DbConverter[] converters = databaseConverterAdapter.getDBConverters();
        Assertions.assertFalse(CollectionUtils.isNullOrEmpty(converters));
    }

    /**
     * This test verify that LockingDBConverterAdapter.getDBConverters(...) returns only Converters
     * Converters which support locking db
     */
    @Test
    void testLockingDBConverterAdapterGetDBConvertersReturnsOnlySupportingLockingDBConverters() {
        final DbConverter converter = ArtifactoryDBVersion.v82.converter();
        Assertions.assertTrue(converter instanceof LockingDBSqlConverter,
                converter.getClass().getSimpleName() + " not supports locking db");
    }
}
