package org.artifactory.storage.db.upgrades.itest.version;

import org.artifactory.storage.db.upgrades.common.UpgradeBaseTest;
import org.artifactory.storage.db.version.ArtifactoryDBVersion;
import org.jfrog.converter.DbVersion;
import org.jfrog.converter.model.ChangeLogContext;
import org.testng.Assert;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import java.io.IOException;
import java.sql.ResultSet;
import java.sql.SQLException;

import static org.artifactory.storage.db.bundle.dao.ArtifactBundlesDao.ARTIFACT_BUNDLES_TABLE;
import static org.artifactory.storage.db.version.ArtifactoryDBVersion.v21;
import static org.artifactory.storage.db.version.ArtifactoryDBVersion.v22;
import static org.testng.Assert.assertFalse;


@Test
public class V22AddTypeColumnWithDefaultValueToArtifactBundlesTest extends UpgradeBaseTest {

    @BeforeMethod
    public void setup() throws IOException, SQLException {

        resetToVersion(v21);

        assertFalse(columnExists(ARTIFACT_BUNDLES_TABLE, "type"));

        DbVersion dbVersion = v22;
        try (ChangeLogContext context = new ChangeLogContext(jdbcHelper.getDataSource().getConnection(),
                dbProperties.getDbType(), dbVersion)) {
            dbVersion.converter().convert(context);
        }
        importSql("/sql/bundles_with_null_type.sql");
    }

    public void testTypeColumnDefaultValueOnArtifactBundlesTable() throws SQLException {
        try (ResultSet res = jdbcHelper.executeSelect("SELECT * FROM artifact_bundles")) {
            while (res.next()) {
                String type = res.getString("type");
                Assert.assertEquals(type, "TARGET");
            }
        }
    }

    @Override
    protected ArtifactoryDBVersion upToVersion() {
        return v22;
    }

}
