package org.artifactory.ui.rest.service.admin.security.group;

import org.artifactory.api.security.UserGroupService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.ArtifactoryRestResponse;
import org.artifactory.ui.rest.model.admin.security.group.Group;
import org.jfrog.access.client.AccessClientException;
import org.jfrog.access.client.AccessClientHttpException;
import org.jfrog.access.rest.group.GroupResponse;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import java.util.List;

import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertTrue;

@Test
public class UpdateGroupServiceTest {

    @Mock
    private UserGroupService userGroupService;
    @Mock
    private ArtifactoryRestRequest<Group> artifactoryRestRequest;
    @Mock
    private GroupResponse groupResponse;

    private UpdateGroupService updateGroupService;
    private AutoCloseable autoCloseable;

    @BeforeMethod
    public void setUp() {
        autoCloseable = MockitoAnnotations.openMocks(this);
        updateGroupService = new UpdateGroupService();
        updateGroupService.setUserGroupService(userGroupService);
    }

    @AfterMethod
    public void tearDown() throws Exception {
        autoCloseable.close();
    }

    @Test
    public void executeCorrectResponseAccessHttpExceptionExpectErrorResponse() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(List.of("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse<Void> restResponse = new ArtifactoryRestResponse<>();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenThrow(new AccessClientHttpException(409, "TestFailMessage"));
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertTrue(restResponse.getFeedbackMsg().getError().contains("Failed to update group testGroup."));
        assertEquals(restResponse.getResponseCode(), 409);
    }

    @Test
    public void executeCorrectResponseExpectErrorResponse() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(List.of("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse<Void> restResponse = new ArtifactoryRestResponse<>();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenThrow(new AccessClientException("TestFailMessage"));
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertTrue(restResponse.getFeedbackMsg().getError().contains("Failed to update group testGroup."));
        assertEquals(restResponse.getResponseCode(), 500);
    }

    @Test
    public void executeCorrectResponseExpect() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(List.of("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse<Void> restResponse = new ArtifactoryRestResponse<>();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenReturn(groupResponse);
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertEquals(restResponse.getResponseCode(), 200);
    }

}
